/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
var app = {
    timerValue: 0,
    
    // Application Constructor
    // direct call to the event if we are not in a cordova app like a browser
    initialize: function() {
        if(window.cordova)
            document.addEventListener('deviceready', this.onDeviceReady.bind(this), false);
        else
            this.onDeviceReady();

    },
    
    // bind to native controls
    overrideBrowserAlert: function() {
        if (navigator.notification && device.platform !='browser') { // Override default HTML alert with native dialog
            window.alert = function (message) {
                navigator.notification.alert(
                    message,    // message
                    null,       // callback
                    "Message de TP 01", // title
                    'Compris'        // buttonName
                );
            };
        }
    },

    // deviceready Event Handler
    //
    // Bind any cordova events here. Common events are:
    // 'pause', 'resume', etc.
    onDeviceReady: function() {
        console.log('identifier: %s', navigator.appInfo.identifier);
        console.log('version: %s', navigator.appInfo.version);
        console.log('build: %s', navigator.appInfo.build);
        console.log("onDeviceReady");

        this.overrideBrowserAlert();
        $('#link-about').click(function(){
            alert("<b>TP 01 pour Ynov</b>\nVersion: " + navigator.appInfo.version + '.' + navigator.appInfo.build);
        });
        
        // dumps the device if exsists
        if(typeof device !== 'undefined'){
            console.log(device);
        }

        this.playStartupSound();
        $('#app').load('views/sensors.html');
   
        if(navigator.splashscreen)
            navigator.splashscreen.hide();
   
        setInterval(this.updateTimer.bind(this), 1000);
        setInterval(this.getRandomData.bind(this), 1000);
       
        this.startCompass();
    },

    // play a mp3 on startup
    playStartupSound: function (){
        if (typeof Media == 'undefined')
            return;
        console.log("playStartupSound");
        var media = new Media(cordova.file.applicationDirectory + 'www/sounds/soft-bells.mp3',
            // success callback
            function () {
                console.log("Audio Success");
            },
            // error callback
            function (err) {
                alert("Audio Error: " +JSON.stringify(err) );
            });
        media.play();
    },

    // increments the timer
    updateTimer: function(){
        this.timerValue++;
        this.updateDom();
    },

    // retrieve remote random data
    getRandomData: function(){
        console.log("getRandomData:" + typeof this);
        var self = this;
        $.getJSON('http://redjuice.net/cordova/random.php', function (data) {
            self.random = data;
            self.updateDom();
            // console.log(data);
        });
        
    },

    // start the compass poller (bousssole)
    startCompass: function(){
        if(navigator.compass){
            var options = {
                frequency: 3000
            }; // Update every 3 seconds
            var self = this;
            var watchID = navigator.compass.watchHeading(
                function(heading){
                   self.heading = heading.magneticHeading+'°';
                   self.updateDom();
                }, 
                function(error){
                    self.heading = "<span style='color:red'>Not Supported</span>";
                    self.updateDom();
                }, options);
        }
        else{
            this.heading = "<span style='color:red'>Not a device</span>";
            this.updateDom();
        }
    }, 

    // update the dom with the object properties
    updateDom: function(){
        $("#sensor-timer").text(this.timerValue);
        $("#sensor-random").text(this.random);
        $('#sensor-heading').html(this.heading);
    }
};



app.initialize();